==> jc-tke-domain-1.1.120-sources.jar: com/xforceplus/ultraman/app/jctke/entity/SubeiAmountApproval.java <==
package com.xforceplus.ultraman.app.jctke.entity;

import java.time.LocalDateTime;
import com.baomidou.mybatisplus.annotation.FieldFill;
import com.baomidou.mybatisplus.annotation.TableField;
import java.io.Serializable;
import java.time.LocalDateTime;
import java.math.BigDecimal;
import java.util.HashMap;
import java.util.Map;
import com.xforceplus.ultraman.bocp.gen.util.BocpGenUtils;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * <p>
 * 
 * </p>
 *
 * @author ultraman
 * @since 2022-08-22
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
public class SubeiAmountApproval implements Serializable {

  private static final long serialVersionUID=1L;

  /**
   * 费用类型
   */
  @TableField("expenseType")
  private String expenseType;

  /**
   * 角色编码
   */
  @TableField("roleType")
  private String roleType;

  /**
   * id
   */
  private Long id;

  /**
   * 租户ID
   */
  @TableField(fill = FieldFill.INSERT)
  private Long tenantId;

  /**
   * 租户代码
   */
  @TableField(fill = FieldFill.INSERT)
  private String tenantCode;

  /**
   * 创建时间
   */
  @TableField(fill = FieldFill.INSERT)
  @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
  private LocalDateTime createTime;

  /**
   * 修改时间
   */
  @TableField(fill = FieldFill.INSERT_UPDATE)
  @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
  private LocalDateTime updateTime;

  /**
   * 创建人ID
   */
  @TableField(fill = FieldFill.INSERT)
  private Long createUserId;

  /**
   * 修改人ID
   */
  @TableField(fill = FieldFill.INSERT_UPDATE)
  private Long updateUserId;

  /**
   * 创建人名字
   */
  @TableField(fill = FieldFill.INSERT)
  private String createUserName;

  /**
   * 修改人名字
   */
  @TableField(fill = FieldFill.INSERT_UPDATE)
  private String updateUserName;

  /**
   * 删除标记
   */
  @TableField(fill = FieldFill.INSERT)
  private String deleteFlag;

  /**
   *  角色序号
   */
  @TableField("roleSerialNumber")
  private Long roleSerialNumber;

  /**
   * 角色英文描述
   */
  @TableField("roleEnglishDescription")
  private String roleEnglishDescription;

  /**
   * 备用金类型
   */
  @TableField("pettyCashType")
  private String pettyCashType;

  /**
   * 备用金金额
   */
  @TableField("pettyCash")
  private Long pettyCash;




  public Map toOQSMap(){
      Map map = new HashMap();
      map.put("expenseType", expenseType);
      map.put("roleType", roleType);
      map.put("id", id);
      map.put("tenant_id", tenantId);
      map.put("tenant_code", tenantCode);
      map.put("create_time", BocpGenUtils.toTimestamp(createTime));
      map.put("update_time", BocpGenUtils.toTimestamp(updateTime));
      map.put("create_user_id", createUserId);
      map.put("update_user_id", updateUserId);
      map.put("create_user_name", createUserName);
      map.put("update_user_name", updateUserName);
      map.put("delete_flag", deleteFlag);
      map.put("roleSerialNumber", roleSerialNumber);
      map.put("roleEnglishDescription", roleEnglishDescription);
      map.put("pettyCashType", pettyCashType);
      map.put("pettyCash", pettyCash);
      return map;
  }

  public static SubeiAmountApproval fromOQSMap(Map map){
    if(map == null || map.isEmpty()) {
      return null;
    }
    SubeiAmountApproval entity = new SubeiAmountApproval();
    if(map.containsKey("expenseType")) {
      Object obj = map.get("expenseType");
      if(obj != null) {
        if(obj instanceof String){
          entity.setExpenseType((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("roleType")) {
      Object obj = map.get("roleType");
      if(obj != null) {
        if(obj instanceof String){
          entity.setRoleType((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("id")) {
      Object obj = map.get("id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setId((Long)obj);
        } else if(obj instanceof String) {
          entity.setId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("tenant_id")) {
      Object obj = map.get("tenant_id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setTenantId((Long)obj);
        } else if(obj instanceof String) {
          entity.setTenantId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setTenantId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("tenant_code")) {
      Object obj = map.get("tenant_code");
      if(obj != null) {
        if(obj instanceof String){
          entity.setTenantCode((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("create_time")) {
      Object obj = map.get("create_time");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setCreateTime(BocpGenUtils.toLocalDateTime((Long)obj));
        } else if(obj instanceof LocalDateTime){
          entity.setCreateTime((LocalDateTime)obj);
        } else if(obj instanceof String) {
          entity.setCreateTime(BocpGenUtils.toLocalDateTime(Long.parseLong((String)obj)));
        }
      } else{
        entity.setCreateTime(null);
      }
    }
    if(map.containsKey("update_time")) {
      Object obj = map.get("update_time");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setUpdateTime(BocpGenUtils.toLocalDateTime((Long)obj));
        } else if(obj instanceof LocalDateTime){
          entity.setUpdateTime((LocalDateTime)obj);
        } else if(obj instanceof String) {
          entity.setUpdateTime(BocpGenUtils.toLocalDateTime(Long.parseLong((String)obj)));
        }
      } else{
        entity.setUpdateTime(null);
      }
    }
    if(map.containsKey("create_user_id")) {
      Object obj = map.get("create_user_id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setCreateUserId((Long)obj);
        } else if(obj instanceof String) {
          entity.setCreateUserId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setCreateUserId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("update_user_id")) {
      Object obj = map.get("update_user_id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setUpdateUserId((Long)obj);
        } else if(obj instanceof String) {
          entity.setUpdateUserId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setUpdateUserId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("create_user_name")) {
      Object obj = map.get("create_user_name");
      if(obj != null) {
        if(obj instanceof String){
          entity.setCreateUserName((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("update_user_name")) {
      Object obj = map.get("update_user_name");
      if(obj != null) {
        if(obj instanceof String){
          entity.setUpdateUserName((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("delete_flag")) {
      Object obj = map.get("delete_flag");
      if(obj != null) {
        if(obj instanceof String){
          entity.setDeleteFlag((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("roleSerialNumber")) {
      Object obj = map.get("roleSerialNumber");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setRoleSerialNumber((Long)obj);
        } else if(obj instanceof String) {
          entity.setRoleSerialNumber(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setRoleSerialNumber(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("roleEnglishDescription")) {
      Object obj = map.get("roleEnglishDescription");
      if(obj != null) {
        if(obj instanceof String){
          entity.setRoleEnglishDescription((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("pettyCashType")) {
      Object obj = map.get("pettyCashType");
      if(obj != null) {
        if(obj instanceof String){
          entity.setPettyCashType((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("pettyCash")) {
      Object obj = map.get("pettyCash");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setPettyCash((Long)obj);
        } else if(obj instanceof String) {
          entity.setPettyCash(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setPettyCash(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    return entity;
  }
}

==> jc-tke-domain-1.1.171-sources.jar: com/xforceplus/ultraman/app/jctke/entity/SubeiAmountApproval.java <==
package com.xforceplus.ultraman.app.jctke.entity;

import java.math.BigDecimal;
import java.time.LocalDateTime;
import com.baomidou.mybatisplus.annotation.FieldFill;
import com.baomidou.mybatisplus.annotation.TableField;
import java.io.Serializable;
import java.time.LocalDateTime;
import java.math.BigDecimal;
import java.util.HashMap;
import java.util.Map;
import com.xforceplus.ultraman.bocp.gen.util.BocpGenUtils;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * <p>
 * 
 * </p>
 *
 * @author ultraman
 * @since 2022-09-01
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
public class SubeiAmountApproval implements Serializable {

  private static final long serialVersionUID=1L;

  /**
   * 费用类型
   */
  @TableField("expenseType")
  private String expenseType;

  /**
   * 角色编码
   */
  @TableField("roleType")
  private String roleType;

  /**
   * id
   */
  private Long id;

  /**
   * 租户ID
   */
  @TableField(fill = FieldFill.INSERT)
  private Long tenantId;

  /**
   * 租户代码
   */
  @TableField(fill = FieldFill.INSERT)
  private String tenantCode;

  /**
   * 创建时间
   */
  @TableField(fill = FieldFill.INSERT)
  @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
  private LocalDateTime createTime;

  /**
   * 修改时间
   */
  @TableField(fill = FieldFill.INSERT_UPDATE)
  @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
  private LocalDateTime updateTime;

  /**
   * 创建人ID
   */
  @TableField(fill = FieldFill.INSERT)
  private Long createUserId;

  /**
   * 修改人ID
   */
  @TableField(fill = FieldFill.INSERT_UPDATE)
  private Long updateUserId;

  /**
   * 创建人名字
   */
  @TableField(fill = FieldFill.INSERT)
  private String createUserName;

  /**
   * 修改人名字
   */
  @TableField(fill = FieldFill.INSERT_UPDATE)
  private String updateUserName;

  /**
   * 删除标记
   */
  @TableField(fill = FieldFill.INSERT)
  private String deleteFlag;

  /**
   *  角色序号
   */
  @TableField("roleSerialNumber")
  private Long roleSerialNumber;

  /**
   * 角色英文描述
   */
  @TableField("roleEnglishDescription")
  private String roleEnglishDescription;

  /**
   * 备用金类型
   */
  @TableField("pettyCashType")
  private String pettyCashType;

  /**
   * 备用金左边界金额
   */
  @TableField("leftSpareAmount")
  private BigDecimal leftSpareAmount;

  /**
   * 备用金右边界金额
   */
  @TableField("rightSpareAmount")
  private BigDecimal rightSpareAmount;

  /**
   * 备用金金额左边界符号
   */
  @TableField("amountLeftBorderSymbol")
  private String amountLeftBorderSymbol;

  /**
   * 备用金金额右边界符号
   */
  @TableField("amountRightBorderSymbol")
  private String amountRightBorderSymbol;




  public Map toOQSMap(){
      Map map = new HashMap();
      map.put("expenseType", expenseType);
      map.put("roleType", roleType);
      map.put("id", id);
      map.put("tenant_id", tenantId);
      map.put("tenant_code", tenantCode);
      map.put("create_time", BocpGenUtils.toTimestamp(createTime));
      map.put("update_time", BocpGenUtils.toTimestamp(updateTime));
      map.put("create_user_id", createUserId);
      map.put("update_user_id", updateUserId);
      map.put("create_user_name", createUserName);
      map.put("update_user_name", updateUserName);
      map.put("delete_flag", deleteFlag);
      map.put("roleSerialNumber", roleSerialNumber);
      map.put("roleEnglishDescription", roleEnglishDescription);
      map.put("pettyCashType", pettyCashType);
      map.put("leftSpareAmount", leftSpareAmount);
      map.put("rightSpareAmount", rightSpareAmount);
      map.put("amountLeftBorderSymbol", amountLeftBorderSymbol);
      map.put("amountRightBorderSymbol", amountRightBorderSymbol);
      return map;
  }

  public static SubeiAmountApproval fromOQSMap(Map map){
    if(map == null || map.isEmpty()) {
      return null;
    }
    SubeiAmountApproval entity = new SubeiAmountApproval();
    if(map.containsKey("expenseType")) {
      Object obj = map.get("expenseType");
      if(obj != null) {
        if(obj instanceof String){
          entity.setExpenseType((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("roleType")) {
      Object obj = map.get("roleType");
      if(obj != null) {
        if(obj instanceof String){
          entity.setRoleType((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("id")) {
      Object obj = map.get("id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setId((Long)obj);
        } else if(obj instanceof String) {
          entity.setId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("tenant_id")) {
      Object obj = map.get("tenant_id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setTenantId((Long)obj);
        } else if(obj instanceof String) {
          entity.setTenantId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setTenantId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("tenant_code")) {
      Object obj = map.get("tenant_code");
      if(obj != null) {
        if(obj instanceof String){
          entity.setTenantCode((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("create_time")) {
      Object obj = map.get("create_time");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setCreateTime(BocpGenUtils.toLocalDateTime((Long)obj));
        } else if(obj instanceof LocalDateTime){
          entity.setCreateTime((LocalDateTime)obj);
        } else if(obj instanceof String) {
          entity.setCreateTime(BocpGenUtils.toLocalDateTime(Long.parseLong((String)obj)));
        }
      } else{
        entity.setCreateTime(null);
      }
    }
    if(map.containsKey("update_time")) {
      Object obj = map.get("update_time");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setUpdateTime(BocpGenUtils.toLocalDateTime((Long)obj));
        } else if(obj instanceof LocalDateTime){
          entity.setUpdateTime((LocalDateTime)obj);
        } else if(obj instanceof String) {
          entity.setUpdateTime(BocpGenUtils.toLocalDateTime(Long.parseLong((String)obj)));
        }
      } else{
        entity.setUpdateTime(null);
      }
    }
    if(map.containsKey("create_user_id")) {
      Object obj = map.get("create_user_id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setCreateUserId((Long)obj);
        } else if(obj instanceof String) {
          entity.setCreateUserId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setCreateUserId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("update_user_id")) {
      Object obj = map.get("update_user_id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setUpdateUserId((Long)obj);
        } else if(obj instanceof String) {
          entity.setUpdateUserId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setUpdateUserId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("create_user_name")) {
      Object obj = map.get("create_user_name");
      if(obj != null) {
        if(obj instanceof String){
          entity.setCreateUserName((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("update_user_name")) {
      Object obj = map.get("update_user_name");
      if(obj != null) {
        if(obj instanceof String){
          entity.setUpdateUserName((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("delete_flag")) {
      Object obj = map.get("delete_flag");
      if(obj != null) {
        if(obj instanceof String){
          entity.setDeleteFlag((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("roleSerialNumber")) {
      Object obj = map.get("roleSerialNumber");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setRoleSerialNumber((Long)obj);
        } else if(obj instanceof String) {
          entity.setRoleSerialNumber(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setRoleSerialNumber(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("roleEnglishDescription")) {
      Object obj = map.get("roleEnglishDescription");
      if(obj != null) {
        if(obj instanceof String){
          entity.setRoleEnglishDescription((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("pettyCashType")) {
      Object obj = map.get("pettyCashType");
      if(obj != null) {
        if(obj instanceof String){
          entity.setPettyCashType((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("leftSpareAmount")) {
      Object obj = map.get("leftSpareAmount");
      if(obj != null) {
        if(obj instanceof BigDecimal) {
          entity.setLeftSpareAmount((BigDecimal)obj);
        } else if(obj instanceof Long) {
          entity.setLeftSpareAmount(BigDecimal.valueOf((Long)obj));
        } else if(obj instanceof Double) {
          entity.setLeftSpareAmount(BigDecimal.valueOf((Double)obj));
        } else if(obj instanceof String) {
          entity.setLeftSpareAmount(new BigDecimal((String)obj));
        } else if(obj instanceof Integer) {
          entity.setLeftSpareAmount(BigDecimal.valueOf(Long.parseLong(obj.toString())));
        }
      } else{
      }
    }
    if(map.containsKey("rightSpareAmount")) {
      Object obj = map.get("rightSpareAmount");
      if(obj != null) {
        if(obj instanceof BigDecimal) {
          entity.setRightSpareAmount((BigDecimal)obj);
        } else if(obj instanceof Long) {
          entity.setRightSpareAmount(BigDecimal.valueOf((Long)obj));
        } else if(obj instanceof Double) {
          entity.setRightSpareAmount(BigDecimal.valueOf((Double)obj));
        } else if(obj instanceof String) {
          entity.setRightSpareAmount(new BigDecimal((String)obj));
        } else if(obj instanceof Integer) {
          entity.setRightSpareAmount(BigDecimal.valueOf(Long.parseLong(obj.toString())));
        }
      } else{
      }
    }
    if(map.containsKey("amountLeftBorderSymbol")) {
      Object obj = map.get("amountLeftBorderSymbol");
      if(obj != null) {
        if(obj instanceof String){
          entity.setAmountLeftBorderSymbol((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("amountRightBorderSymbol")) {
      Object obj = map.get("amountRightBorderSymbol");
      if(obj != null) {
        if(obj instanceof String){
          entity.setAmountRightBorderSymbol((String)obj);
        }
      } else{
      }
    }
    return entity;
  }
}
